leaftools.get_leaf_in_expr_with_minimum_prolated_duration
=========================================================

.. autofunction:: abjad.tools.leaftools.get_leaf_in_expr_with_minimum_prolated_duration.get_leaf_in_expr_with_minimum_prolated_duration
